@@ -9,7 +9,7 @@ from .np_extractor import NPExtractor
 from .decorators import cached_property
 from .utils import lowerstrip, strip_punc
 from .inflect import singularize, pluralize
-from .feelings import sentiment as _sentiment
+from .sentiments import sentiment as _sentiment
 
 
 class WordList(list):
